""" Tecan tip carriers """

# pylint: disable=empty-docstring
# pylint: disable=invalid-name
# pylint: disable=line-too-long

from typing import List, Optional
from pylabrobot.resources.carrier import (
  TipCarrier,
  CarrierSite,
  create_carrier_sites,
  create_homogeneous_carrier_sites
)
from pylabrobot.resources.coordinate import Coordinate
from pylabrobot.resources.tecan.tecan_resource import TecanResource


class TecanTipCarrier(TipCarrier, TecanResource):
  """ Base class for Tecan tip carriers. """

  def __init__(
    self,
    name: str,
    size_x: float,
    size_y: float,
    size_z: float,
    off_x: float,
    off_y: float,
    sites: Optional[List[CarrierSite]] = None,
    category="tecan_tip_carrier",
    model: Optional[str] = None):
    super().__init__(name, size_x, size_y, size_z,
      sites, category=category, model=model)

    self.off_x: float = off_x
    self.off_y: float = off_y


def Washstation_2Grid_Trough_DiTi(name: str) -> TecanTipCarrier:
  """ Tecan part no. 10650037 """
  return TecanTipCarrier(
    name=name,
    size_x=50.0,
    size_y=352.0,
    size_z=6.0,
    off_x=12.5,
    off_y=14.5,
    sites=create_carrier_sites(locations = [
        Coordinate(0.0, 352.0, 6.0),
        Coordinate(0.0, -15.0, 6.0),
        Coordinate(25.5, 94.6, 16.0),
        Coordinate(25.5, 182.0, 16.0),
        Coordinate(25.5, 269.4, 16.0),
        Coordinate(0.0, 111.0, 6.0),
        Coordinate(0.0, 184.0, 6.0),
        Coordinate(0.0, 278.0, 6.0),
      ], site_size_x=[
        0.0,
        50.0,
        24.0,
        24.0,
        24.0,
        25.0,
        25.0,
        25.0,
      ], site_size_y=[
        0.0,
        93.0,
        84.0,
        84.0,
        84.0,
        71.0,
        92.0,
        71.0,
    ]),
    model="Washstation_2Grid_Trough_DiTi"
  )


def MCA384_DiTi_Carrier(name: str) -> TecanTipCarrier:
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=369.5,
    size_z=154.0,
    off_x=13.3,
    off_y=22.2,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(11.7, 46.7, 31.0),
        Coordinate(11.7, 186.8, 31.0),
      ],
      site_size_x=122.0,
      site_size_y=86.0,
    ),
    model="MCA384_DiTi_Carrier"
  )


def DiTi_2Pos___Waste(name: str) -> TecanTipCarrier:
  """ Tecan part no. 10613012 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=374.0,
    size_z=4.5,
    off_x=12.0,
    off_y=24.7,
    sites=create_carrier_sites(locations = [
        Coordinate(3.0, 0.0, 4.5),
        Coordinate(13.3, 170.0, 4.5),
        Coordinate(13.3, 270.0, 4.5),
      ], site_size_x=[
        143.0,
        127.0,
        127.0,
      ], site_size_y=[
        155.0,
        88.5,
        88.5,
    ]),
    model="DiTi_2Pos___Waste"
  )


def DiTi_3Pos(name: str) -> TecanTipCarrier:
  """ Tecan part no. 10613022 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=374.0,
    size_z=4.5,
    off_x=12.0,
    off_y=24.7,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(13.3, 70.0, 4.5),
        Coordinate(13.3, 170.0, 4.5),
        Coordinate(13.3, 270.0, 4.5),
      ],
      site_size_x=127.0,
      site_size_y=88.5,
    ),
    model="DiTi_3Pos"
  )


def DiTi_SBS_3_Pos_MCA96(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020043 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=6.0,
    off_x=12.0,
    off_y=11.0,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 12.0, 6.0),
        Coordinate(10.5, 108.0, 6.0),
        Coordinate(10.5, 204.0, 6.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_SBS_3_Pos_MCA96"
  )


def LI___DiTi_3Pos(name: str) -> TecanTipCarrier:
  """ Tecan part no. 10650036 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=350.0,
    size_z=4.5,
    off_x=12.0,
    off_y=24.7,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(13.4, 42.5, -2.5),
        Coordinate(13.3, 138.7, -2.5),
        Coordinate(13.3, 234.1, -2.5),
      ],
      site_size_x=127.0,
      site_size_y=88.5,
    ),
    model="LI___DiTi_3Pos"
  )


def DiTi_SBS_2P_Waste_MCA96(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020045 """
  return TecanTipCarrier(
    name=name,
    size_x=159.0,
    size_y=374.0,
    size_z=6.0,
    off_x=25.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(20.0, -41.0, 125.0),
        Coordinate(23.5, 184.0, 6.0),
        Coordinate(23.5, 280.0, 6.0),
      ], site_size_x=[
        138.0,
        127.0,
        127.0,
      ], site_size_y=[
        155.0,
        88.5,
        88.5,
    ]),
    model="DiTi_SBS_2P_Waste_MCA96"
  )


def DiTi_SBS_4_Pos_MCA96(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020044 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=6.0,
    off_x=12.5,
    off_y=51.5,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.0, 3.0, 6.0),
        Coordinate(10.0, 99.0, 6.0),
        Coordinate(10.0, 195.0, 6.0),
        Coordinate(10.0, 291.0, 6.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_SBS_4_Pos_MCA96"
  )


def DiTi_Nest_2P_W_MCA384(name: str) -> TecanTipCarrier:
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=4.0,
    off_x=12.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(-7.0, -97.0, 4.0),
        Coordinate(10.5, 105.0, 4.0),
        Coordinate(10.5, 201.0, 4.0),
        Coordinate(-7.0, -97.0, 4.0),
        Coordinate(-7.0, -97.0, 4.0),
        Coordinate(-7.0, -97.0, 4.0),
        Coordinate(-7.0, -97.0, 4.0),
        Coordinate(-7.0, -97.0, 4.0),
        Coordinate(-7.0, -97.0, 4.0),
        Coordinate(-7.0, -97.0, 4.0),
        Coordinate(-7.0, -97.0, 164.0),
        Coordinate(10.5, 105.0, 46.0),
        Coordinate(10.5, 201.0, 46.0),
        Coordinate(10.5, 105.0, 60.0),
        Coordinate(10.5, 201.0, 60.0),
        Coordinate(10.5, 105.0, 74.0),
        Coordinate(10.5, 201.0, 74.0),
        Coordinate(10.5, 105.0, 88.0),
        Coordinate(10.5, 201.0, 88.0),
        Coordinate(10.5, 105.0, 102.0),
        Coordinate(10.5, 201.0, 102.0),
        Coordinate(10.5, 105.0, 116.0),
        Coordinate(10.5, 201.0, 116.0),
        Coordinate(10.5, 105.0, 130.0),
        Coordinate(10.5, 201.0, 130.0),
        Coordinate(10.5, 105.0, 144.0),
        Coordinate(10.5, 201.0, 144.0),
      ], site_size_x=[
        155.0,
        127.0,
        127.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        142.0,
        88.5,
        88.5,
        142.0,
        142.0,
        142.0,
        142.0,
        142.0,
        142.0,
        142.0,
        142.0,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
    ]),
    model="DiTi_Nest_2P_W_MCA384"
  )


def DiTi_Nest_2P_W_MCA384_Indiv(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30053521 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.0,
    off_x=12.5,
    off_y=51.5,
    sites=create_carrier_sites(locations = [
        Coordinate(-7.0, -52.0, 4.0),
        Coordinate(10.5, 144.0, 4.0),
        Coordinate(10.5, 288.0, 4.0),
        Coordinate(-7.0, -52.0, 4.0),
        Coordinate(-7.0, -52.0, 4.0),
        Coordinate(-7.0, -52.0, 4.0),
        Coordinate(-7.0, -52.0, 4.0),
        Coordinate(-7.0, -52.0, 4.0),
        Coordinate(-7.0, -52.0, 4.0),
        Coordinate(-7.0, -52.0, 4.0),
        Coordinate(-7.0, -52.0, 164.0),
        Coordinate(10.5, 144.0, 46.0),
        Coordinate(10.5, 288.0, 46.0),
        Coordinate(10.5, 144.0, 60.0),
        Coordinate(10.5, 288.0, 60.0),
        Coordinate(10.5, 144.0, 74.0),
        Coordinate(10.5, 288.0, 74.0),
        Coordinate(10.5, 144.0, 88.0),
        Coordinate(10.5, 288.0, 88.0),
        Coordinate(10.5, 144.0, 102.0),
        Coordinate(10.5, 288.0, 102.0),
        Coordinate(10.5, 144.0, 116.0),
        Coordinate(10.5, 288.0, 116.0),
        Coordinate(10.5, 144.0, 130.0),
        Coordinate(10.5, 288.0, 130.0),
        Coordinate(10.5, 144.0, 144.0),
        Coordinate(10.5, 288.0, 144.0),
      ], site_size_x=[
        155.0,
        127.0,
        127.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        142.0,
        88.5,
        88.5,
        142.0,
        142.0,
        142.0,
        142.0,
        142.0,
        142.0,
        142.0,
        142.0,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
    ]),
    model="DiTi_Nest_2P_W_MCA384_Indiv"
  )


def DiTi_Nest_3_Pos_MCA384_Indiv(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30053521 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.0,
    off_x=12.5,
    off_y=51.5,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 3.0, 4.0),
        Coordinate(10.5, 147.0, 4.0),
        Coordinate(10.5, 291.0, 4.0),
        Coordinate(10.5, 3.0, 46.0),
        Coordinate(10.5, 147.0, 46.0),
        Coordinate(10.5, 291.0, 46.0),
        Coordinate(10.5, 3.0, 60.0),
        Coordinate(10.5, 147.0, 60.0),
        Coordinate(10.5, 291.0, 60.0),
        Coordinate(10.5, 3.0, 74.0),
        Coordinate(10.5, 147.0, 74.0),
        Coordinate(10.5, 291.0, 74.0),
        Coordinate(10.5, 3.0, 88.0),
        Coordinate(10.5, 147.0, 88.0),
        Coordinate(10.5, 291.0, 88.0),
        Coordinate(10.5, 3.0, 102.0),
        Coordinate(10.5, 147.0, 102.0),
        Coordinate(10.5, 291.0, 102.0),
        Coordinate(10.5, 3.0, 116.0),
        Coordinate(10.5, 147.0, 116.0),
        Coordinate(10.5, 291.0, 116.0),
        Coordinate(10.5, 3.0, 130.0),
        Coordinate(10.5, 147.0, 130.0),
        Coordinate(10.5, 291.0, 130.0),
        Coordinate(10.5, 3.0, 144.0),
        Coordinate(10.5, 147.0, 144.0),
        Coordinate(10.5, 291.0, 144.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_3_Pos_MCA384_Indiv"
  )


def DiTi_Nested_3_Pos_MCA384(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052707 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=4.0,
    off_x=12.0,
    off_y=11.0,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 12.0, 4.0),
        Coordinate(10.5, 108.0, 4.0),
        Coordinate(10.5, 204.0, 4.0),
        Coordinate(10.5, 12.0, 46.0),
        Coordinate(10.5, 108.0, 46.0),
        Coordinate(10.5, 204.0, 46.0),
        Coordinate(10.5, 12.0, 60.0),
        Coordinate(10.5, 108.0, 60.0),
        Coordinate(10.5, 204.0, 60.0),
        Coordinate(10.5, 12.0, 74.0),
        Coordinate(10.5, 108.0, 74.0),
        Coordinate(10.5, 204.0, 74.0),
        Coordinate(10.5, 12.0, 88.0),
        Coordinate(10.5, 108.0, 88.0),
        Coordinate(10.5, 204.0, 88.0),
        Coordinate(10.5, 12.0, 102.0),
        Coordinate(10.5, 108.0, 102.0),
        Coordinate(10.5, 204.0, 102.0),
        Coordinate(10.5, 12.0, 116.0),
        Coordinate(10.5, 108.0, 116.0),
        Coordinate(10.5, 204.0, 116.0),
        Coordinate(10.5, 12.0, 130.0),
        Coordinate(10.5, 108.0, 130.0),
        Coordinate(10.5, 204.0, 130.0),
        Coordinate(10.5, 12.0, 144.0),
        Coordinate(10.5, 108.0, 144.0),
        Coordinate(10.5, 204.0, 144.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nested_3_Pos_MCA384"
  )


def DiTi_Nested_4_Pos_MCA384(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052708 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.0,
    off_x=12.5,
    off_y=51.5,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 3.0, 4.0),
        Coordinate(10.5, 99.0, 4.0),
        Coordinate(10.5, 195.0, 4.0),
        Coordinate(10.5, 291.0, 4.0),
        Coordinate(10.5, 3.0, 46.0),
        Coordinate(10.5, 99.0, 46.0),
        Coordinate(10.5, 195.0, 46.0),
        Coordinate(10.5, 291.0, 46.0),
        Coordinate(10.5, 3.0, 60.0),
        Coordinate(10.5, 99.0, 60.0),
        Coordinate(10.5, 195.0, 60.0),
        Coordinate(10.5, 291.0, 60.0),
        Coordinate(10.5, 3.0, 74.0),
        Coordinate(10.5, 99.0, 74.0),
        Coordinate(10.5, 195.0, 74.0),
        Coordinate(10.5, 291.0, 74.0),
        Coordinate(10.5, 3.0, 88.0),
        Coordinate(10.5, 99.0, 88.0),
        Coordinate(10.5, 195.0, 88.0),
        Coordinate(10.5, 291.0, 88.0),
        Coordinate(10.5, 3.0, 102.0),
        Coordinate(10.5, 99.0, 102.0),
        Coordinate(10.5, 195.0, 102.0),
        Coordinate(10.5, 291.0, 102.0),
        Coordinate(10.5, 3.0, 116.0),
        Coordinate(10.5, 99.0, 116.0),
        Coordinate(10.5, 195.0, 116.0),
        Coordinate(10.5, 291.0, 116.0),
        Coordinate(10.5, 3.0, 130.0),
        Coordinate(10.5, 99.0, 130.0),
        Coordinate(10.5, 195.0, 130.0),
        Coordinate(10.5, 291.0, 130.0),
        Coordinate(10.5, 3.0, 144.0),
        Coordinate(10.5, 99.0, 144.0),
        Coordinate(10.5, 195.0, 144.0),
        Coordinate(10.5, 291.0, 144.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nested_4_Pos_MCA384"
  )


def DiTi_SBS_2P_W_MCA38_Indiv(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30053521 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.0,
    off_x=12.0,
    off_y=51.5,
    sites=create_carrier_sites(locations = [
        Coordinate(-7.0, -53.5, 164.0),
        Coordinate(10.5, 144.0, 4.0),
        Coordinate(10.5, 288.0, 4.0),
      ], site_size_x=[
        155.0,
        127.0,
        127.0,
      ], site_size_y=[
        142.0,
        88.5,
        88.5,
    ]),
    model="DiTi_SBS_2P_W_MCA38_Indiv"
  )


def DiTi_SBS_2P_W_MCA384(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052707 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=4.0,
    off_x=12.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(-7.0, -97.0, 164.0),
        Coordinate(10.5, 105.0, 4.0),
        Coordinate(10.5, 201.0, 4.0),
      ], site_size_x=[
        155.0,
        127.0,
        127.0,
      ], site_size_y=[
        142.0,
        88.5,
        88.5,
    ]),
    model="DiTi_SBS_2P_W_MCA384"
  )


def DiTi_SBS_3_Pos_MCA384(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052707 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=4.0,
    off_x=12.0,
    off_y=11.0,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 12.0, 4.0),
        Coordinate(10.5, 108.0, 4.0),
        Coordinate(10.5, 204.0, 4.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_SBS_3_Pos_MCA384"
  )


def DiTi_SBS_3_Pos_MCA384_Indiv(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30053521 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.0,
    off_x=12.5,
    off_y=51.5,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 3.0, 4.0),
        Coordinate(10.5, 147.0, 4.0),
        Coordinate(10.5, 291.0, 4.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_SBS_3_Pos_MCA384_Indiv"
  )


def DiTi_SBS_4_Pos_MCA384(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052708 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.0,
    off_x=12.5,
    off_y=51.5,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 3.0, 4.0),
        Coordinate(10.5, 99.0, 4.0),
        Coordinate(10.5, 195.0, 4.0),
        Coordinate(10.5, 291.0, 4.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_SBS_4_Pos_MCA384"
  )


def DiTi_Nest_2_W_MCA96_100(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020043 or 30020044 """
  return TecanTipCarrier(
    name=name,
    size_x=159.0,
    size_y=374.0,
    size_z=6.0,
    off_x=25.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(23.5, 184.0, 6.0),
        Coordinate(23.5, 280.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 168.0),
        Coordinate(23.5, 184.0, 48.0),
        Coordinate(23.5, 280.0, 48.0),
        Coordinate(23.5, 184.0, 62.0),
        Coordinate(23.5, 280.0, 62.0),
        Coordinate(23.5, 184.0, 76.0),
        Coordinate(23.5, 280.0, 76.0),
        Coordinate(23.5, 184.0, 90.0),
        Coordinate(23.5, 280.0, 90.0),
        Coordinate(23.5, 184.0, 104.0),
        Coordinate(23.5, 280.0, 104.0),
        Coordinate(23.5, 184.0, 118.0),
        Coordinate(23.5, 280.0, 118.0),
        Coordinate(23.5, 184.0, 132.0),
        Coordinate(23.5, 280.0, 132.0),
        Coordinate(23.5, 184.0, 146.0),
        Coordinate(23.5, 280.0, 146.0),
      ], site_size_x=[
        138.0,
        127.0,
        127.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        155.0,
        88.5,
        88.5,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
    ]),
    model="DiTi_Nest_2_W_MCA96_100"
  )


def DiTi_Nest_2_W_MCA96_200(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020043 or 30020044 """
  return TecanTipCarrier(
    name=name,
    size_x=159.0,
    size_y=374.0,
    size_z=6.0,
    off_x=25.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(23.5, 184.0, 6.0),
        Coordinate(23.5, 280.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 168.0),
        Coordinate(23.5, 184.0, 48.0),
        Coordinate(23.5, 280.0, 48.0),
        Coordinate(23.5, 184.0, 62.0),
        Coordinate(23.5, 280.0, 62.0),
        Coordinate(23.5, 184.0, 76.0),
        Coordinate(23.5, 280.0, 76.0),
        Coordinate(23.5, 184.0, 90.0),
        Coordinate(23.5, 280.0, 90.0),
        Coordinate(23.5, 184.0, 104.0),
        Coordinate(23.5, 280.0, 104.0),
        Coordinate(23.5, 184.0, 118.0),
        Coordinate(23.5, 280.0, 118.0),
        Coordinate(23.5, 184.0, 132.0),
        Coordinate(23.5, 280.0, 132.0),
        Coordinate(23.5, 184.0, 146.0),
        Coordinate(23.5, 280.0, 146.0),
      ], site_size_x=[
        138.0,
        127.0,
        127.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        155.0,
        88.5,
        88.5,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
    ]),
    model="DiTi_Nest_2_W_MCA96_200"
  )


def DiTi_Nest_2_W_MCA96_50(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020043 or 30020044 """
  return TecanTipCarrier(
    name=name,
    size_x=159.0,
    size_y=374.0,
    size_z=6.0,
    off_x=25.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(23.5, 184.0, 6.0),
        Coordinate(23.5, 280.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 168.0),
        Coordinate(23.5, 184.0, 48.0),
        Coordinate(23.5, 280.0, 48.0),
        Coordinate(23.5, 184.0, 62.0),
        Coordinate(23.5, 280.0, 62.0),
        Coordinate(23.5, 184.0, 76.0),
        Coordinate(23.5, 280.0, 76.0),
        Coordinate(23.5, 184.0, 90.0),
        Coordinate(23.5, 280.0, 90.0),
        Coordinate(23.5, 184.0, 104.0),
        Coordinate(23.5, 280.0, 104.0),
        Coordinate(23.5, 184.0, 118.0),
        Coordinate(23.5, 280.0, 118.0),
        Coordinate(23.5, 184.0, 132.0),
        Coordinate(23.5, 280.0, 132.0),
        Coordinate(23.5, 184.0, 146.0),
        Coordinate(23.5, 280.0, 146.0),
      ], site_size_x=[
        138.0,
        127.0,
        127.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        155.0,
        88.5,
        88.5,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
    ]),
    model="DiTi_Nest_2_W_MCA96_50"
  )


def DiTi_Nest_3_Pos_MCA96_100(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020043 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=6.0,
    off_x=12.0,
    off_y=11.0,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 12.0, 6.0),
        Coordinate(10.5, 108.0, 6.0),
        Coordinate(10.5, 204.0, 6.0),
        Coordinate(10.5, 12.0, 48.0),
        Coordinate(10.5, 108.0, 48.0),
        Coordinate(10.5, 204.0, 48.0),
        Coordinate(10.5, 12.0, 62.0),
        Coordinate(10.5, 108.0, 62.0),
        Coordinate(10.5, 204.0, 62.0),
        Coordinate(10.5, 12.0, 76.0),
        Coordinate(10.5, 108.0, 76.0),
        Coordinate(10.5, 204.0, 76.0),
        Coordinate(10.5, 12.0, 90.0),
        Coordinate(10.5, 108.0, 90.0),
        Coordinate(10.5, 204.0, 90.0),
        Coordinate(10.5, 12.0, 104.0),
        Coordinate(10.5, 108.0, 104.0),
        Coordinate(10.5, 204.0, 104.0),
        Coordinate(10.5, 12.0, 118.0),
        Coordinate(10.5, 108.0, 118.0),
        Coordinate(10.5, 204.0, 118.0),
        Coordinate(10.5, 12.0, 132.0),
        Coordinate(10.5, 108.0, 132.0),
        Coordinate(10.5, 204.0, 132.0),
        Coordinate(10.5, 12.0, 146.0),
        Coordinate(10.5, 108.0, 146.0),
        Coordinate(10.5, 204.0, 146.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_3_Pos_MCA96_100"
  )


def DiTi_Nest_3_Pos_MCA96_200(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020043 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=6.0,
    off_x=12.0,
    off_y=11.0,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 12.0, 6.0),
        Coordinate(10.5, 108.0, 6.0),
        Coordinate(10.5, 204.0, 6.0),
        Coordinate(10.5, 12.0, 48.0),
        Coordinate(10.5, 108.0, 48.0),
        Coordinate(10.5, 204.0, 48.0),
        Coordinate(10.5, 12.0, 62.0),
        Coordinate(10.5, 108.0, 62.0),
        Coordinate(10.5, 204.0, 62.0),
        Coordinate(10.5, 12.0, 76.0),
        Coordinate(10.5, 108.0, 76.0),
        Coordinate(10.5, 204.0, 76.0),
        Coordinate(10.5, 12.0, 90.0),
        Coordinate(10.5, 108.0, 90.0),
        Coordinate(10.5, 204.0, 90.0),
        Coordinate(10.5, 12.0, 104.0),
        Coordinate(10.5, 108.0, 104.0),
        Coordinate(10.5, 204.0, 104.0),
        Coordinate(10.5, 12.0, 118.0),
        Coordinate(10.5, 108.0, 118.0),
        Coordinate(10.5, 204.0, 118.0),
        Coordinate(10.5, 12.0, 132.0),
        Coordinate(10.5, 108.0, 132.0),
        Coordinate(10.5, 204.0, 132.0),
        Coordinate(10.5, 12.0, 146.0),
        Coordinate(10.5, 108.0, 146.0),
        Coordinate(10.5, 204.0, 146.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_3_Pos_MCA96_200"
  )


def DiTi_Nest_3_Pos_MCA96_50(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020043 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=6.0,
    off_x=12.0,
    off_y=11.0,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 12.0, 6.0),
        Coordinate(10.5, 108.0, 6.0),
        Coordinate(10.5, 204.0, 6.0),
        Coordinate(10.5, 12.0, 48.0),
        Coordinate(10.5, 108.0, 48.0),
        Coordinate(10.5, 204.0, 48.0),
        Coordinate(10.5, 12.0, 62.0),
        Coordinate(10.5, 108.0, 62.0),
        Coordinate(10.5, 204.0, 62.0),
        Coordinate(10.5, 12.0, 76.0),
        Coordinate(10.5, 108.0, 76.0),
        Coordinate(10.5, 204.0, 76.0),
        Coordinate(10.5, 12.0, 90.0),
        Coordinate(10.5, 108.0, 90.0),
        Coordinate(10.5, 204.0, 90.0),
        Coordinate(10.5, 12.0, 104.0),
        Coordinate(10.5, 108.0, 104.0),
        Coordinate(10.5, 204.0, 104.0),
        Coordinate(10.5, 12.0, 118.0),
        Coordinate(10.5, 108.0, 118.0),
        Coordinate(10.5, 204.0, 118.0),
        Coordinate(10.5, 12.0, 132.0),
        Coordinate(10.5, 108.0, 132.0),
        Coordinate(10.5, 204.0, 132.0),
        Coordinate(10.5, 12.0, 146.0),
        Coordinate(10.5, 108.0, 146.0),
        Coordinate(10.5, 204.0, 146.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_3_Pos_MCA96_50"
  )


def DiTi_Nest_4_Pos_MCA96_100(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020044 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=6.0,
    off_x=12.5,
    off_y=51.5,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.0, 3.0, 6.0),
        Coordinate(10.0, 99.0, 6.0),
        Coordinate(10.0, 195.0, 6.0),
        Coordinate(10.0, 291.0, 6.0),
        Coordinate(10.0, 3.0, 48.0),
        Coordinate(10.0, 99.0, 48.0),
        Coordinate(10.0, 195.0, 48.0),
        Coordinate(10.0, 291.0, 48.0),
        Coordinate(10.0, 3.0, 62.0),
        Coordinate(10.0, 99.0, 62.0),
        Coordinate(10.0, 195.0, 62.0),
        Coordinate(10.0, 291.0, 62.0),
        Coordinate(10.0, 3.0, 76.0),
        Coordinate(10.0, 99.0, 76.0),
        Coordinate(10.0, 195.0, 76.0),
        Coordinate(10.0, 291.0, 76.0),
        Coordinate(10.0, 3.0, 90.0),
        Coordinate(10.0, 99.0, 90.0),
        Coordinate(10.0, 195.0, 90.0),
        Coordinate(10.0, 291.0, 90.0),
        Coordinate(10.0, 3.0, 104.0),
        Coordinate(10.0, 99.0, 104.0),
        Coordinate(10.0, 195.0, 104.0),
        Coordinate(10.0, 291.0, 104.0),
        Coordinate(10.0, 3.0, 118.0),
        Coordinate(10.0, 99.0, 118.0),
        Coordinate(10.0, 195.0, 118.0),
        Coordinate(10.0, 291.0, 118.0),
        Coordinate(10.0, 3.0, 132.0),
        Coordinate(10.0, 99.0, 132.0),
        Coordinate(10.0, 195.0, 132.0),
        Coordinate(10.0, 291.0, 132.0),
        Coordinate(10.0, 3.0, 146.0),
        Coordinate(10.0, 99.0, 146.0),
        Coordinate(10.0, 195.0, 146.0),
        Coordinate(10.0, 291.0, 146.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_4_Pos_MCA96_100"
  )


def DiTi_Nest_4_Pos_MCA96_200(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020044 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=6.0,
    off_x=12.5,
    off_y=51.5,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.0, 3.0, 6.0),
        Coordinate(10.0, 99.0, 6.0),
        Coordinate(10.0, 195.0, 6.0),
        Coordinate(10.0, 291.0, 6.0),
        Coordinate(10.0, 3.0, 48.0),
        Coordinate(10.0, 99.0, 48.0),
        Coordinate(10.0, 195.0, 48.0),
        Coordinate(10.0, 291.0, 48.0),
        Coordinate(10.0, 3.0, 62.0),
        Coordinate(10.0, 99.0, 62.0),
        Coordinate(10.0, 195.0, 62.0),
        Coordinate(10.0, 291.0, 62.0),
        Coordinate(10.0, 3.0, 76.0),
        Coordinate(10.0, 99.0, 76.0),
        Coordinate(10.0, 195.0, 76.0),
        Coordinate(10.0, 291.0, 76.0),
        Coordinate(10.0, 3.0, 90.0),
        Coordinate(10.0, 99.0, 90.0),
        Coordinate(10.0, 195.0, 90.0),
        Coordinate(10.0, 291.0, 90.0),
        Coordinate(10.0, 3.0, 104.0),
        Coordinate(10.0, 99.0, 104.0),
        Coordinate(10.0, 195.0, 104.0),
        Coordinate(10.0, 291.0, 104.0),
        Coordinate(10.0, 3.0, 118.0),
        Coordinate(10.0, 99.0, 118.0),
        Coordinate(10.0, 195.0, 118.0),
        Coordinate(10.0, 291.0, 118.0),
        Coordinate(10.0, 3.0, 132.0),
        Coordinate(10.0, 99.0, 132.0),
        Coordinate(10.0, 195.0, 132.0),
        Coordinate(10.0, 291.0, 132.0),
        Coordinate(10.0, 3.0, 146.0),
        Coordinate(10.0, 99.0, 146.0),
        Coordinate(10.0, 195.0, 146.0),
        Coordinate(10.0, 291.0, 146.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_4_Pos_MCA96_200"
  )


def DiTi_Nest_4_Pos_MCA96_50(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020044 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=6.0,
    off_x=12.5,
    off_y=51.5,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.0, 3.0, 6.0),
        Coordinate(10.0, 99.0, 6.0),
        Coordinate(10.0, 195.0, 6.0),
        Coordinate(10.0, 291.0, 6.0),
        Coordinate(10.0, 3.0, 48.0),
        Coordinate(10.0, 99.0, 48.0),
        Coordinate(10.0, 195.0, 48.0),
        Coordinate(10.0, 291.0, 48.0),
        Coordinate(10.0, 3.0, 62.0),
        Coordinate(10.0, 99.0, 62.0),
        Coordinate(10.0, 195.0, 62.0),
        Coordinate(10.0, 291.0, 62.0),
        Coordinate(10.0, 3.0, 76.0),
        Coordinate(10.0, 99.0, 76.0),
        Coordinate(10.0, 195.0, 76.0),
        Coordinate(10.0, 291.0, 76.0),
        Coordinate(10.0, 3.0, 90.0),
        Coordinate(10.0, 99.0, 90.0),
        Coordinate(10.0, 195.0, 90.0),
        Coordinate(10.0, 291.0, 90.0),
        Coordinate(10.0, 3.0, 104.0),
        Coordinate(10.0, 99.0, 104.0),
        Coordinate(10.0, 195.0, 104.0),
        Coordinate(10.0, 291.0, 104.0),
        Coordinate(10.0, 3.0, 118.0),
        Coordinate(10.0, 99.0, 118.0),
        Coordinate(10.0, 195.0, 118.0),
        Coordinate(10.0, 291.0, 118.0),
        Coordinate(10.0, 3.0, 132.0),
        Coordinate(10.0, 99.0, 132.0),
        Coordinate(10.0, 195.0, 132.0),
        Coordinate(10.0, 291.0, 132.0),
        Coordinate(10.0, 3.0, 146.0),
        Coordinate(10.0, 99.0, 146.0),
        Coordinate(10.0, 195.0, 146.0),
        Coordinate(10.0, 291.0, 146.0),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_4_Pos_MCA96_50"
  )


def DiTi_3Pos___Waste(name: str) -> TecanTipCarrier:
  """ Tecan part no. 10762023 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=450.0,
    size_z=4.5,
    off_x=12.0,
    off_y=24.7,
    sites=create_carrier_sites(locations = [
        Coordinate(6.0, 20.0, 4.5),
        Coordinate(13.3, 167.0, 4.5),
        Coordinate(13.3, 256.5, 4.5),
        Coordinate(13.3, 346.0, 4.5),
      ], site_size_x=[
        137.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        155.0,
        88.5,
        88.5,
        88.5,
    ]),
    model="DiTi_3Pos___Waste"
  )


def DiTi_Nest_2_W_MCA384_100(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020043 or 30020044 """
  return TecanTipCarrier(
    name=name,
    size_x=159.0,
    size_y=374.0,
    size_z=6.0,
    off_x=25.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(23.5, 184.0, 6.0),
        Coordinate(23.5, 280.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 168.0),
        Coordinate(23.5, 184.0, 48.0),
        Coordinate(23.5, 280.0, 48.0),
        Coordinate(23.5, 184.0, 62.0),
        Coordinate(23.5, 280.0, 62.0),
        Coordinate(23.5, 184.0, 76.0),
        Coordinate(23.5, 280.0, 76.0),
        Coordinate(23.5, 184.0, 90.0),
        Coordinate(23.5, 280.0, 90.0),
        Coordinate(23.5, 184.0, 104.0),
        Coordinate(23.5, 280.0, 104.0),
        Coordinate(23.5, 184.0, 118.0),
        Coordinate(23.5, 280.0, 118.0),
        Coordinate(23.5, 184.0, 132.0),
        Coordinate(23.5, 280.0, 132.0),
        Coordinate(23.5, 184.0, 146.0),
        Coordinate(23.5, 280.0, 146.0),
      ], site_size_x=[
        138.0,
        127.0,
        127.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        155.0,
        88.5,
        88.5,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
    ]),
    model="DiTi_Nest_2_W_MCA384_100"
  )


def DiTi_Nest_2_W_MCA384_200(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020043 or 30020044 """
  return TecanTipCarrier(
    name=name,
    size_x=159.0,
    size_y=374.0,
    size_z=6.0,
    off_x=25.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(23.5, 184.0, 6.0),
        Coordinate(23.5, 280.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 168.0),
        Coordinate(23.5, 184.0, 48.0),
        Coordinate(23.5, 280.0, 48.0),
        Coordinate(23.5, 184.0, 62.0),
        Coordinate(23.5, 280.0, 62.0),
        Coordinate(23.5, 184.0, 76.0),
        Coordinate(23.5, 280.0, 76.0),
        Coordinate(23.5, 184.0, 90.0),
        Coordinate(23.5, 280.0, 90.0),
        Coordinate(23.5, 184.0, 104.0),
        Coordinate(23.5, 280.0, 104.0),
        Coordinate(23.5, 184.0, 118.0),
        Coordinate(23.5, 280.0, 118.0),
        Coordinate(23.5, 184.0, 132.0),
        Coordinate(23.5, 280.0, 132.0),
        Coordinate(23.5, 184.0, 146.0),
        Coordinate(23.5, 280.0, 146.0),
      ], site_size_x=[
        138.0,
        127.0,
        127.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        155.0,
        88.5,
        88.5,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
    ]),
    model="DiTi_Nest_2_W_MCA384_200"
  )


def DiTi_Nest_2_W_MCA384_50(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30020043 or 30020044 """
  return TecanTipCarrier(
    name=name,
    size_x=159.0,
    size_y=374.0,
    size_z=6.0,
    off_x=25.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(23.5, 184.0, 6.0),
        Coordinate(23.5, 280.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 6.0),
        Coordinate(20.0, -41.0, 168.0),
        Coordinate(23.5, 184.0, 48.0),
        Coordinate(23.5, 280.0, 48.0),
        Coordinate(23.5, 184.0, 62.0),
        Coordinate(23.5, 280.0, 62.0),
        Coordinate(23.5, 184.0, 76.0),
        Coordinate(23.5, 280.0, 76.0),
        Coordinate(23.5, 184.0, 90.0),
        Coordinate(23.5, 280.0, 90.0),
        Coordinate(23.5, 184.0, 104.0),
        Coordinate(23.5, 280.0, 104.0),
        Coordinate(23.5, 184.0, 118.0),
        Coordinate(23.5, 280.0, 118.0),
        Coordinate(23.5, 184.0, 132.0),
        Coordinate(23.5, 280.0, 132.0),
        Coordinate(23.5, 184.0, 146.0),
        Coordinate(23.5, 280.0, 146.0),
      ], site_size_x=[
        138.0,
        127.0,
        127.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        138.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        155.0,
        88.5,
        88.5,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        155.0,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
        88.5,
    ]),
    model="DiTi_Nest_2_W_MCA384_50"
  )


def DiTi_Waste_station_6_Trough(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30073056 """
  return TecanTipCarrier(
    name=name,
    size_x=50.0,
    size_y=352.0,
    size_z=6.0,
    off_x=12.5,
    off_y=14.5,
    sites=create_carrier_sites(locations = [
        Coordinate(0.0, 352.0, 6.0),
        Coordinate(0.0, -15.0, 6.0),
        Coordinate(25.5, 94.6, 16.0),
        Coordinate(25.5, 182.0, 16.0),
        Coordinate(25.5, 269.4, 16.0),
        Coordinate(1.0, 94.6, 16.0),
        Coordinate(1.0, 182.0, 16.0),
        Coordinate(1.0, 269.4, 16.0),
      ], site_size_x=[
        0.0,
        50.0,
        24.0,
        24.0,
        24.0,
        24.0,
        24.0,
        24.0,
      ], site_size_y=[
        0.0,
        93.0,
        84.0,
        84.0,
        84.0,
        84.0,
        84.0,
        84.0,
    ]),
    model="DiTi_Waste_station_6_Trough"
  )


def DiTi_Nest_2_W_LiHa_350(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052707. Usable with DiTi nested Waste LiHa, Tecan part no. 30089580 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=4.5,
    off_x=12.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 136.5),
        Coordinate(10.5, 108.0, 57.5),
        Coordinate(10.5, 108.0, 78.5),
        Coordinate(10.5, 108.0, 99.5),
        Coordinate(10.5, 108.0, 120.5),
        Coordinate(10.5, 108.0, 141.5),
        Coordinate(10.5, 204.0, 57.5),
        Coordinate(10.5, 204.0, 78.5),
        Coordinate(10.5, 204.0, 99.5),
        Coordinate(10.5, 204.0, 120.5),
        Coordinate(10.5, 204.0, 141.5),
      ], site_size_x=[
        146.0,
        146.0,
        146.0,
        146.0,
        146.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        152.0,
        152.0,
        152.0,
        152.0,
        152.0,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
    ]),
    model="DiTi_Nest_2_W_LiHa_350"
  )


def DiTi_Nest_3_Pos_LiHa_350(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052707 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=4.5,
    off_x=12.0,
    off_y=11.0,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 12.0, 57.5),
        Coordinate(10.5, 12.0, 78.5),
        Coordinate(10.5, 12.0, 99.5),
        Coordinate(10.5, 12.0, 120.5),
        Coordinate(10.5, 12.0, 141.5),
        Coordinate(10.5, 108.0, 57.5),
        Coordinate(10.5, 108.0, 78.5),
        Coordinate(10.5, 108.0, 99.5),
        Coordinate(10.5, 108.0, 120.5),
        Coordinate(10.5, 108.0, 141.5),
        Coordinate(10.5, 204.0, 57.5),
        Coordinate(10.5, 204.0, 78.5),
        Coordinate(10.5, 204.0, 99.5),
        Coordinate(10.5, 204.0, 120.5),
        Coordinate(10.5, 204.0, 141.5),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_3_Pos_LiHa_350"
  )


def DiTi_Nest_3_W_LiHa_350(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052708. Usable with DiTi nested Waste LiHa, Tecan part no. 30089580 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.5,
    off_x=12.5,
    off_y=51.5,
    sites=create_carrier_sites(locations = [
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 136.5),
        Coordinate(10.5, 99.0, 57.5),
        Coordinate(10.5, 99.0, 78.5),
        Coordinate(10.5, 99.0, 99.5),
        Coordinate(10.5, 99.0, 120.5),
        Coordinate(10.5, 99.0, 141.5),
        Coordinate(10.5, 195.0, 57.5),
        Coordinate(10.5, 195.0, 78.5),
        Coordinate(10.5, 195.0, 99.5),
        Coordinate(10.5, 195.0, 120.5),
        Coordinate(10.5, 195.0, 141.5),
        Coordinate(10.5, 291.0, 57.5),
        Coordinate(10.5, 291.0, 78.5),
        Coordinate(10.5, 291.0, 99.5),
        Coordinate(10.5, 291.0, 120.5),
        Coordinate(10.5, 291.0, 141.5),
      ], site_size_x=[
        146.0,
        146.0,
        146.0,
        146.0,
        146.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        152.0,
        152.0,
        152.0,
        152.0,
        152.0,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
    ]),
    model="DiTi_Nest_3_W_LiHa_350"
  )


def DiTi_Nest_4_Pos_LiHa_350(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052708 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.5,
    off_x=12.5,
    off_y=51.5,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 3.0, 57.5),
        Coordinate(10.5, 3.0, 78.5),
        Coordinate(10.5, 3.0, 99.5),
        Coordinate(10.5, 3.0, 120.5),
        Coordinate(10.5, 3.0, 141.5),
        Coordinate(10.5, 99.0, 57.5),
        Coordinate(10.5, 99.0, 78.5),
        Coordinate(10.5, 99.0, 99.5),
        Coordinate(10.5, 99.0, 120.5),
        Coordinate(10.5, 99.0, 141.5),
        Coordinate(10.5, 195.0, 57.5),
        Coordinate(10.5, 195.0, 78.5),
        Coordinate(10.5, 195.0, 99.5),
        Coordinate(10.5, 195.0, 120.5),
        Coordinate(10.5, 195.0, 141.5),
        Coordinate(10.5, 291.0, 57.5),
        Coordinate(10.5, 291.0, 78.5),
        Coordinate(10.5, 291.0, 99.5),
        Coordinate(10.5, 291.0, 120.5),
        Coordinate(10.5, 291.0, 141.5),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_4_Pos_LiHa_350"
  )


def DiTi_Nest_2_W_LiHa_10(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052707. Usable with DiTi nested Waste LiHa, Tecan part no. 30089580 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=4.5,
    off_x=12.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 136.5),
        Coordinate(10.5, 108.0, 57.5),
        Coordinate(10.5, 108.0, 78.5),
        Coordinate(10.5, 108.0, 99.5),
        Coordinate(10.5, 108.0, 120.5),
        Coordinate(10.5, 108.0, 141.5),
        Coordinate(10.5, 204.0, 57.5),
        Coordinate(10.5, 204.0, 78.5),
        Coordinate(10.5, 204.0, 99.5),
        Coordinate(10.5, 204.0, 120.5),
        Coordinate(10.5, 204.0, 141.5),
      ], site_size_x=[
        146.0,
        146.0,
        146.0,
        146.0,
        146.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        152.0,
        152.0,
        152.0,
        152.0,
        152.0,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
    ]),
    model="DiTi_Nest_2_W_LiHa_10"
  )


def DiTi_Nest_2_W_LiHa_10_F(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052707. Usable with DiTi nested Waste LiHa, Tecan part no. 30089580 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=4.5,
    off_x=12.0,
    off_y=11.0,
    sites=create_carrier_sites(locations = [
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 4.5),
        Coordinate(10.5, -137.0, 136.5),
        Coordinate(10.5, 108.0, 57.5),
        Coordinate(10.5, 108.0, 78.5),
        Coordinate(10.5, 108.0, 99.5),
        Coordinate(10.5, 108.0, 120.5),
        Coordinate(10.5, 108.0, 141.5),
        Coordinate(10.5, 204.0, 57.5),
        Coordinate(10.5, 204.0, 78.5),
        Coordinate(10.5, 204.0, 99.5),
        Coordinate(10.5, 204.0, 120.5),
        Coordinate(10.5, 204.0, 141.5),
      ], site_size_x=[
        146.0,
        146.0,
        146.0,
        146.0,
        146.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        152.0,
        152.0,
        152.0,
        152.0,
        152.0,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
    ]),
    model="DiTi_Nest_2_W_LiHa_10_F"
  )


def DiTi_Nest_3_Pos_LiHa_10(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052707 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=4.5,
    off_x=12.0,
    off_y=11.0,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 12.0, 57.5),
        Coordinate(10.5, 12.0, 78.5),
        Coordinate(10.5, 12.0, 99.5),
        Coordinate(10.5, 12.0, 120.5),
        Coordinate(10.5, 12.0, 141.5),
        Coordinate(10.5, 108.0, 57.5),
        Coordinate(10.5, 108.0, 78.5),
        Coordinate(10.5, 108.0, 99.5),
        Coordinate(10.5, 108.0, 120.5),
        Coordinate(10.5, 108.0, 141.5),
        Coordinate(10.5, 204.0, 57.5),
        Coordinate(10.5, 204.0, 78.5),
        Coordinate(10.5, 204.0, 99.5),
        Coordinate(10.5, 204.0, 120.5),
        Coordinate(10.5, 204.0, 141.5),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_3_Pos_LiHa_10"
  )


def DiTi_Nest_3_Pos_LiHa_10_F(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052707 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=295.0,
    size_z=4.5,
    off_x=12.0,
    off_y=11.0,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 12.0, 57.5),
        Coordinate(10.5, 12.0, 78.5),
        Coordinate(10.5, 12.0, 99.5),
        Coordinate(10.5, 12.0, 120.5),
        Coordinate(10.5, 12.0, 141.5),
        Coordinate(10.5, 108.0, 57.5),
        Coordinate(10.5, 108.0, 78.5),
        Coordinate(10.5, 108.0, 99.5),
        Coordinate(10.5, 108.0, 120.5),
        Coordinate(10.5, 108.0, 141.5),
        Coordinate(10.5, 204.0, 57.5),
        Coordinate(10.5, 204.0, 78.5),
        Coordinate(10.5, 204.0, 99.5),
        Coordinate(10.5, 204.0, 120.5),
        Coordinate(10.5, 204.0, 141.5),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_3_Pos_LiHa_10_F"
  )


def DiTi_Nest_3_W_LiHa_10(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052708. Usable with DiTi nested Waste LiHa, Tecan part no. 30089580 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.5,
    off_x=12.5,
    off_y=51.5,
    sites=create_carrier_sites(locations = [
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 136.5),
        Coordinate(10.5, 99.0, 57.5),
        Coordinate(10.5, 99.0, 78.5),
        Coordinate(10.5, 99.0, 99.5),
        Coordinate(10.5, 99.0, 120.5),
        Coordinate(10.5, 99.0, 141.5),
        Coordinate(10.5, 195.0, 57.5),
        Coordinate(10.5, 195.0, 78.5),
        Coordinate(10.5, 195.0, 99.5),
        Coordinate(10.5, 195.0, 120.5),
        Coordinate(10.5, 195.0, 141.5),
        Coordinate(10.5, 291.0, 57.5),
        Coordinate(10.5, 291.0, 78.5),
        Coordinate(10.5, 291.0, 99.5),
        Coordinate(10.5, 291.0, 120.5),
        Coordinate(10.5, 291.0, 141.5),
      ], site_size_x=[
        146.0,
        146.0,
        146.0,
        146.0,
        146.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        152.0,
        152.0,
        152.0,
        152.0,
        152.0,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
    ]),
    model="DiTi_Nest_3_W_LiHa_10"
  )


def DiTi_Nest_3_W_LiHa_10_F(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052708. Usable with DiTi nested Waste LiHa, Tecan part no. 30089580 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.5,
    off_x=12.5,
    off_y=51.5,
    sites=create_carrier_sites(locations = [
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 4.5),
        Coordinate(10.5, -92.0, 136.5),
        Coordinate(10.5, 99.0, 57.5),
        Coordinate(10.5, 99.0, 78.5),
        Coordinate(10.5, 99.0, 99.5),
        Coordinate(10.5, 99.0, 120.5),
        Coordinate(10.5, 99.0, 141.5),
        Coordinate(10.5, 195.0, 57.5),
        Coordinate(10.5, 195.0, 78.5),
        Coordinate(10.5, 195.0, 99.5),
        Coordinate(10.5, 195.0, 120.5),
        Coordinate(10.5, 195.0, 141.5),
        Coordinate(10.5, 291.0, 57.5),
        Coordinate(10.5, 291.0, 78.5),
        Coordinate(10.5, 291.0, 99.5),
        Coordinate(10.5, 291.0, 120.5),
        Coordinate(10.5, 291.0, 141.5),
      ], site_size_x=[
        146.0,
        146.0,
        146.0,
        146.0,
        146.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
        127.0,
      ], site_size_y=[
        152.0,
        152.0,
        152.0,
        152.0,
        152.0,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
        85.5,
    ]),
    model="DiTi_Nest_3_W_LiHa_10_F"
  )


def DiTi_Nest_4_Pos_LiHa_10(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052708 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.5,
    off_x=12.5,
    off_y=51.5,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 3.0, 57.5),
        Coordinate(10.5, 3.0, 78.5),
        Coordinate(10.5, 3.0, 99.5),
        Coordinate(10.5, 3.0, 120.5),
        Coordinate(10.5, 3.0, 141.5),
        Coordinate(10.5, 99.0, 57.5),
        Coordinate(10.5, 99.0, 78.5),
        Coordinate(10.5, 99.0, 99.5),
        Coordinate(10.5, 99.0, 120.5),
        Coordinate(10.5, 99.0, 141.5),
        Coordinate(10.5, 195.0, 57.5),
        Coordinate(10.5, 195.0, 78.5),
        Coordinate(10.5, 195.0, 99.5),
        Coordinate(10.5, 195.0, 120.5),
        Coordinate(10.5, 195.0, 141.5),
        Coordinate(10.5, 291.0, 57.5),
        Coordinate(10.5, 291.0, 78.5),
        Coordinate(10.5, 291.0, 99.5),
        Coordinate(10.5, 291.0, 120.5),
        Coordinate(10.5, 291.0, 141.5),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_4_Pos_LiHa_10"
  )


def DiTi_Nest_4_Pos_LiHa_10_F(name: str) -> TecanTipCarrier:
  """ Tecan part no. 30052708 """
  return TecanTipCarrier(
    name=name,
    size_x=149.0,
    size_y=380.0,
    size_z=4.5,
    off_x=12.5,
    off_y=51.5,
    sites=create_homogeneous_carrier_sites(locations=[
        Coordinate(10.5, 3.0, 57.5),
        Coordinate(10.5, 3.0, 78.5),
        Coordinate(10.5, 3.0, 99.5),
        Coordinate(10.5, 3.0, 120.5),
        Coordinate(10.5, 3.0, 141.5),
        Coordinate(10.5, 99.0, 57.5),
        Coordinate(10.5, 99.0, 78.5),
        Coordinate(10.5, 99.0, 99.5),
        Coordinate(10.5, 99.0, 120.5),
        Coordinate(10.5, 99.0, 141.5),
        Coordinate(10.5, 195.0, 57.5),
        Coordinate(10.5, 195.0, 78.5),
        Coordinate(10.5, 195.0, 99.5),
        Coordinate(10.5, 195.0, 120.5),
        Coordinate(10.5, 195.0, 141.5),
        Coordinate(10.5, 291.0, 57.5),
        Coordinate(10.5, 291.0, 78.5),
        Coordinate(10.5, 291.0, 99.5),
        Coordinate(10.5, 291.0, 120.5),
        Coordinate(10.5, 291.0, 141.5),
      ],
      site_size_x=127.0,
      site_size_y=85.5,
    ),
    model="DiTi_Nest_4_Pos_LiHa_10_F"
  )
